@@ -12,6 +12,7 @@
 #
 ##############################################################################
 import unittest
+
 from transaction._compat import JYTHON
 
 
@@ -27,6 +28,7 @@ class WeakSetTests(unittest.TestCase):
 
     def test_len(self):
         import gc
+
         from transaction.weakset import WeakSet
         w = WeakSet()
         d1 = Dummy()
@@ -36,8 +38,10 @@ class WeakSetTests(unittest.TestCase):
         self.assertEqual(len(w), 2)
         del d1
         gc.collect()
-        if not JYTHON:
+        if JYTHON:
             # The Jython GC is non deterministic
+            pass  # pragma: no cover
+        else:
             self.assertEqual(len(w), 1)
 
     def test_remove(self):
@@ -64,6 +68,7 @@ class WeakSetTests(unittest.TestCase):
 
     def test_as_weakref_list(self):
         import gc
+
         from transaction.weakset import WeakSet
         w = WeakSet()
         dummy = Dummy()
@@ -99,6 +104,7 @@ class WeakSetTests(unittest.TestCase):
 
     def test_map_w_gced_element(self):
         import gc
+
         from transaction.weakset import WeakSet
         w = WeakSet()
         dummy = Dummy()
